@@ -760,9 +760,19 @@ where
                                 true
                             }
                         }
-                        Some(Value::Dimension(n)) => {
+                        Some(Value::Dimension(dimension)) => {
                             if self.config.minify {
-                                let minified = minify_numeric(n.value.value);
+                                let value = match dimension {
+                                    Dimension::Length(i) => i.value.value,
+                                    Dimension::Angle(i) => i.value.value,
+                                    Dimension::Time(i) => i.value.value,
+                                    Dimension::Frequency(i) => i.value.value,
+                                    Dimension::Resolution(i) => i.value.value,
+                                    Dimension::Flex(i) => i.value.value,
+                                    Dimension::UnknownDimension(i) => i.value.value,
+                                };
+
+                                let minified = minify_numeric(value);
 
                                 !minified.starts_with('.')
                             } else {
@@ -1050,6 +1060,55 @@ where
 
     #[emitter]
     fn emit_dimension(&mut self, n: &Dimension) -> Result {
+        match n {
+            Dimension::Length(n) => emit!(self, n),
+            Dimension::Angle(n) => emit!(self, n),
+            Dimension::Time(n) => emit!(self, n),
+            Dimension::Frequency(n) => emit!(self, n),
+            Dimension::Resolution(n) => emit!(self, n),
+            Dimension::Flex(n) => emit!(self, n),
+            Dimension::UnknownDimension(n) => emit!(self, n),
+        }
+    }
+
+    #[emitter]
+    fn emit_lenth(&mut self, n: &Length) -> Result {
+        emit!(self, n.value);
+        emit!(self, n.unit);
+    }
+
+    #[emitter]
+    fn emit_angle(&mut self, n: &Angle) -> Result {
+        emit!(self, n.value);
+        emit!(self, n.unit);
+    }
+
+    #[emitter]
+    fn emit_time(&mut self, n: &Time) -> Result {
+        emit!(self, n.value);
+        emit!(self, n.unit);
+    }
+
+    #[emitter]
+    fn emit_frequency(&mut self, n: &Frequency) -> Result {
+        emit!(self, n.value);
+        emit!(self, n.unit);
+    }
+
+    #[emitter]
+    fn emit_resolution(&mut self, n: &Resolution) -> Result {
+        emit!(self, n.value);
+        emit!(self, n.unit);
+    }
+
+    #[emitter]
+    fn emit_flex(&mut self, n: &Flex) -> Result {
+        emit!(self, n.value);
+        emit!(self, n.unit);
+    }
+
+    #[emitter]
+    fn emit_unknown_dimension(&mut self, n: &UnknownDimension) -> Result {
         emit!(self, n.value);
         emit!(self, n.unit);
     }
